#ifndef suse_h
#define suse_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_suse: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_suse */
public:
	MODULE_suse (void);
	int dohtml (const char *key);
	int execmain (int argc, char *argv[], bool);
    /*~PROTOEND~ MODULE_suse */
};

class ROUTES;
class HOSTS;
class HOSTINFO;
class VIEWITEMS;
class PPPONE;
class USER;
class SHADOW;
class SERVICES;

#define HELP_SUSE "suse"

#include "suse.p"

#endif







